@@ -294,7 +294,7 @@ namespace Banshee.MediaEngine
             bool found = false;
             if (ServiceManager.DbConnection != null) {
                 // Try to find uri in the library
-                int track_id = DatabaseTrackInfo.GetTrackIdForUri (uri);
+                long track_id = DatabaseTrackInfo.GetTrackIdForUri (uri);
                 if (track_id > 0) {
                     DatabaseTrackInfo track_db = DatabaseTrackInfo.Provider.FetchSingle (track_id);
                     found = true;
@@ -499,6 +499,16 @@ namespace Banshee.MediaEngine
             }
         }
 
+        public void RestartCurrentTrack ()
+        {
+            var track = CurrentTrack;
+            if (track != null) {
+                // Don't process the track as played through IncrementLastPlayed, just play it again
+                active_engine.Close (false);
+                OpenPlay (track);
+            }
+        }
+
         // For use by RadioTrackInfo
         // TODO remove this method once RadioTrackInfo playlist downloading/parsing logic moved here?
         internal void StartSynthesizeContacting (TrackInfo track)
@@ -528,6 +538,16 @@ namespace Banshee.MediaEngine
             }
         }
 
+        public void Seek (uint position, bool accurate_seek)
+        {
+            active_engine.Seek (position, accurate_seek);
+        }
+
+        public void Seek (uint position)
+        {
+            Seek (position, false);
+        }
+
         public void VideoExpose (IntPtr displayContext, bool direct)
         {
             active_engine.VideoExpose (displayContext, direct);
