@@ -119,7 +119,7 @@ namespace Banshee.Gui
                     Catalog.GetString ("Edit information on selected tracks"), OnTrackEditor),
 
                 new ActionEntry ("TrackPropertiesAction", Stock.Properties,
-                    Catalog.GetString ("Properties"), null,
+                    Catalog.GetString ("Properties"), "",
                     Catalog.GetString ("View information on selected tracks"), OnTrackProperties),
 
                 new ActionEntry ("PlayTrack", null,
@@ -639,5 +639,32 @@ namespace Banshee.Gui
             }
             return ret;
         }
+
+        public static bool ConfirmRemove (string header)
+        {
+            string message = Catalog.GetString ("Are you sure you want to continue?");
+
+            bool remove_tracks = false;
+            ThreadAssist.BlockingProxyToMain (() => {
+
+                var md = new HigMessageDialog (
+                    ServiceManager.Get<GtkElementsService> ().PrimaryWindow,
+                    DialogFlags.DestroyWithParent, MessageType.Warning,
+                    ButtonsType.None, header, message
+                );
+                md.AddButton ("gtk-cancel", ResponseType.No, true);
+                md.AddButton (Catalog.GetString ("Remove tracks"), ResponseType.Yes, false);
+
+                try {
+                    if (md.Run () == (int) ResponseType.Yes) {
+                        remove_tracks = true;
+                    }
+                } finally {
+                    md.Destroy ();
+                }
+            });
+            return remove_tracks;
+        }
+
     }
 }
