@@ -64,7 +64,7 @@ namespace Banshee.Dap.AppleDevice
             get; set;
         }
 
-        private Dictionary<int, AppleDeviceTrackInfo> tracks_map = new Dictionary<int, AppleDeviceTrackInfo> (); // FIXME: EPIC FAIL
+        private Dictionary<long, AppleDeviceTrackInfo> tracks_map = new Dictionary<long, AppleDeviceTrackInfo> (); // FIXME: EPIC FAIL
 
         public event EventHandler<ScrobblingBatchEventArgs> ReadyToScrobble;
 
@@ -183,7 +183,7 @@ namespace Banshee.Dap.AppleDevice
 
                 try {
                     MediaDatabase = new GPod.ITDB (Device.Mountpoint);
-                } catch (GLib.GException e) {
+                } catch (Exception e) {
                     Log.Exception ("iPod database could not be loaded, creating a new one", e);
                     if (GPod.ITDB.InitIpod (Volume.MountPoint, null, Volume.Name)) {
                         // this may throw again. In the future we need to implement some kind of alert
@@ -404,6 +404,10 @@ namespace Banshee.Dap.AppleDevice
             get { return false; }//!database_supported; }
         }
 
+        public override string BaseDirectory {
+            get { return Volume.MountPoint; }
+        }
+
         public override void Import ()
         {
             Banshee.ServiceStack.ServiceManager.Get<LibraryImportManager> ().Enqueue (GPod.ITDB.GetMusicPath (Device));
@@ -570,7 +574,7 @@ namespace Banshee.Dap.AppleDevice
 
             SyncTracksToAdd (progressUpdater);
 
-            SyncTracksToUpdate ();
+            SyncTracksToUpdate (progressUpdater);
 
             SyncTracksToRemove (progressUpdater);
 
@@ -611,8 +615,10 @@ namespace Banshee.Dap.AppleDevice
             }
         }
 
-        void SyncTracksToUpdate ()
+        void SyncTracksToUpdate (UserJob progressUpdater)
         {
+            string message = Catalog.GetString ("Updating metadata in track {0} of {1}");
+            int total = tracks_to_update.Count;
             while (tracks_to_update.Count > 0) {
                 AppleDeviceTrackInfo track = null;
                 lock (sync_mutex) {
@@ -620,6 +626,8 @@ namespace Banshee.Dap.AppleDevice
                 }
 
                 try {
+                    UpdateProgress (progressUpdater, message, total - tracks_to_update.Count, total);
+
                     track.CommitToIpod (MediaDatabase);
                 } catch (Exception e) {
                     Log.Exception ("Cannot save track to iPod", e);
@@ -654,13 +662,16 @@ namespace Banshee.Dap.AppleDevice
                 }
             }
 
-            SyncRemovalOfInvalidTracks ();
+            SyncRemovalOfInvalidTracks (progressUpdater);
         }
 
-        void SyncRemovalOfInvalidTracks ()
+        void SyncRemovalOfInvalidTracks (UserJob progressUpdater)
         {
+            string message = Catalog.GetString ("Cleaning up, removing invalid track {0} of {1}");
+            int total = invalid_tracks_in_device.Count;
             while (invalid_tracks_in_device.Count > 0) {
                 try {
+                    UpdateProgress (progressUpdater, message, total - invalid_tracks_in_device.Count, total);
                     DeleteTrack (invalid_tracks_in_device.Dequeue (), false);
                 } catch (Exception e) {
                     Log.Exception ("Cannot remove invalid track from iPod", e);
@@ -688,7 +699,7 @@ namespace Banshee.Dap.AppleDevice
                 if (from != null && from.Count > 0) {
                     var playlist = new GPod.Playlist (from.Name);
                     MediaDatabase.Playlists.Add (playlist);
-                    foreach (int track_id in ServiceManager.DbConnection.QueryEnumerable<int> (String.Format (
+                    foreach (long track_id in ServiceManager.DbConnection.QueryEnumerable<long> (String.Format (
                         "SELECT CoreTracks.TrackID FROM {0} WHERE {1}",
                         from.DatabaseTrackModel.ConditionFromFragment, from.DatabaseTrackModel.Condition)))
                     {
