@@ -53,7 +53,7 @@ namespace Banshee.Dap.Mtp
     {
 		private MtpDevice mtp_device;
         //private bool supports_jpegs = false;
-        private Dictionary<int, Track> track_map;
+        private Dictionary<long, Track> track_map;
 
         private Dictionary<string, Album> album_cache = new Dictionary<string, Album> ();
 
@@ -149,7 +149,7 @@ namespace Banshee.Dap.Mtp
 
         protected override void LoadFromDevice ()
         {
-            track_map = new Dictionary<int, Track> ();
+            track_map = new Dictionary<long, Track> ();
             try {
                 List<Track> files = null;
                 lock (mtp_device) {
@@ -176,7 +176,7 @@ namespace Banshee.Dap.Mtp
                 }
 
                 foreach (Track mtp_track in files) {
-                    int track_id;
+                    long track_id;
                     if ((track_id = DatabaseTrackInfo.GetTrackIdForUri (MtpTrackInfo.GetPathFromMtpTrack (mtp_track), DbId )) > 0) {
                         track_map[track_id] = mtp_track;
                     } else {
@@ -263,7 +263,7 @@ namespace Banshee.Dap.Mtp
             get { return !(IsAdding || IsDeleting); }
         }
 
-        private static SafeUri empty_file = new SafeUri (Paths.Combine (Paths.ApplicationCache, "mtp.mp3"));
+        private SafeUri empty_file = new SafeUri (Paths.Combine (Paths.ApplicationCache, "mtp.mp3"));
         protected override void OnTracksDeleted ()
         {
             // Hack to get the disk usage indicate to be accurate, which seems to
@@ -294,7 +294,7 @@ namespace Banshee.Dap.Mtp
         private long bytes_used;
         public override long BytesUsed {
             get {
-                if (Monitor.TryEnter (mtp_device)) {
+                if (mtp_device != null && Monitor.TryEnter (mtp_device)) {
                     try {
                         bytes_used = 0;
                         foreach (DeviceStorage s in mtp_device.GetStorage ()) {
