@@ -93,8 +93,6 @@ namespace Banshee.PlayQueue
             ServiceManager.PlayerEngine.ConnectEvent (OnPlayerEvent);
             ServiceManager.PlaybackController.TrackStarted += OnTrackStarted;
 
-            // TODO change this Gtk.Action code so that the actions can be removed.  And so this
-            // class doesn't depend on Gtk/ThickClient.
             actions = new PlayQueueActions (this);
 
             Properties.SetString ("ActiveSourceUIResource", "ActiveSourceUI.xml");
@@ -239,7 +237,7 @@ namespace Banshee.PlayQueue
             }
         }
 
-        private void EnqueueId (int trackId, bool prepend, bool generated)
+        private void EnqueueId (long trackId, bool prepend, bool generated)
         {
             if (trackId <= 0) {
                 return;
@@ -551,7 +549,7 @@ namespace Banshee.PlayQueue
 
         private void BindToDatabase ()
         {
-            int result = ServiceManager.DbConnection.Query<int> (
+            long result = ServiceManager.DbConnection.Query<long> (
                 "SELECT PlaylistID FROM CorePlaylists WHERE Special = 1 AND Name = ? LIMIT 1",
                 special_playlist_name
             );
@@ -1017,7 +1015,7 @@ namespace Banshee.PlayQueue
 
         public static readonly SchemaEntry<string> PopulateFromSchema = new SchemaEntry<string> (
             "plugins.play_queue", "populate_from",
-            ServiceManager.SourceManager.MusicLibrary.Name,
+            MusicLibrarySource.SourceName,
             "Source to poplulate from",
             "Name of the source to populate the the Play Queue from"
         );
