@@ -4,8 +4,11 @@
 // Authors:
 //   Bertrand Lorentz <bertrand.lorentz@gmail.com>
 //   Phil Trimble <philtrimble@gmail.com>
+//   Andres G. Aragoneses <knocte@gmail.com>
 //
 // Copyright (C) 2009 Bertrand Lorentz
+// Copyright (C) 2013 Phil Trimble
+// Copyright (C) 2013 Andres G. Aragoneses
 //
 // Permission is hereby granted, free of charge, to any person obtaining
 // a copy of this software and associated documentation files (the
@@ -29,6 +32,7 @@
 
 using System;
 using System.Collections.Generic;
+using System.Collections.Specialized;
 using System.IO;
 using System.Net;
 using System.Text;
@@ -54,6 +58,18 @@ namespace Lastfm
 
     public delegate void SendRequestHandler ();
 
+    public class MaxSizeExceededException : ApplicationException
+    {
+    }
+
+    internal class WebRequestCreator : IWebRequestCreate
+    {
+        public WebRequest Create (Uri uri)
+        {
+            return (HttpWebRequest) HttpWebRequest.Create (uri);
+        }
+    }
+
     public class LastfmRequest
     {
         private const string API_ROOT = "http://ws.audioscrobbler.com/2.0/";
@@ -61,10 +77,17 @@ namespace Lastfm
         private Dictionary<string, string> parameters = new Dictionary<string, string> ();
         private Stream response_stream;
         private string response_string;
+        IWebRequestCreate web_request_creator;
 
         public LastfmRequest ()
         {}
 
+        internal LastfmRequest (string method, RequestType request_type, ResponseFormat response_format, IWebRequestCreate web_request_creator)
+            : this (method, request_type, response_format)
+        {
+            this.web_request_creator = web_request_creator;
+        }
+
         public LastfmRequest (string method) : this (method, RequestType.Read, ResponseFormat.Json)
         {}
 
@@ -73,25 +96,86 @@ namespace Lastfm
             this.method = method;
             this.request_type = request_type;
             this.response_format = response_format;
+            if (this.web_request_creator == null) {
+                this.web_request_creator = new WebRequestCreator ();
+            }
+
+            Init ();
+        }
+
+        private void Init ()
+        {
+            this.incremental_data = new StringBuilder ();
+
+            if (request_type != RequestType.Write) {
+                incremental_data.Append (API_ROOT);
+            }
+            incremental_data.AppendFormat ("?method={0}", method);
+            incremental_data.AppendFormat ("&api_key={0}", LastfmCore.ApiKey);
+
+            if (request_type == RequestType.AuthenticatedRead || request_type == RequestType.Write) {
+                AddParameter ("sk", LastfmCore.Account.SessionKey);
+            }
+
+            if (response_format == ResponseFormat.Json) {
+                AddParameter ("format", "json");
+            } else if (response_format == ResponseFormat.Raw) {
+                AddParameter ("raw", "true");
+            }
         }
 
         private string method;
-        public string Method { get; set; }
-
 
         private RequestType request_type;
-        public RequestType RequestType { get; set; }
-
 
         private ResponseFormat response_format;
-        public ResponseFormat ResponseFormat { get; set; }
 
+        private StringBuilder incremental_data;
+
+        // This is close to the max based on testing.
+        private const int MAX_POST_LENGTH = 7000;
 
         public void AddParameter (string param_name, string param_value)
         {
+            var chunk = String.Format ("&{0}={1}",
+                                       param_name, param_value != null ? Uri.EscapeDataString (param_value) : null);
+
+            CheckSize (chunk.Length);
+
+            incremental_data.Append (chunk);
             parameters.Add (param_name, param_value);
         }
 
+        public void AddParameters (NameValueCollection parms)
+        {
+            var chunks = new StringBuilder ();
+            foreach (string key in parms) {
+                var value = parms [key];
+                chunks.AppendFormat ("&{0}={1}",
+                                     key, value != null ? Uri.EscapeDataString (value) : null);
+            }
+
+            CheckSize (chunks.Length);
+
+            incremental_data.Append (chunks.ToString ());
+            foreach (string key in parms) {
+                var value = parms [key];
+                parameters.Add (key, value);
+            }
+        }
+
+        private void CheckSize (int length)
+        {
+            var target_length = incremental_data.Length + length;
+            if (request_type != RequestType.Read) {
+                target_length += 9 + 32; // length of &api_sig={GetSignature()}
+            }
+
+            if (target_length > MAX_POST_LENGTH) {
+                throw new MaxSizeExceededException ();
+            }
+        }
+
         public Stream GetResponseStream ()
         {
             return response_stream;
@@ -103,12 +187,6 @@ namespace Lastfm
                 throw new InvalidOperationException ("The method name should be set");
             }
 
-            if (response_format == ResponseFormat.Json) {
-                AddParameter ("format", "json");
-            } else if (response_format == ResponseFormat.Raw) {
-                AddParameter ("raw", "true");
-            }
-
             if (request_type == RequestType.Write) {
                 response_stream = Post (API_ROOT, BuildPostData ());
             } else {
@@ -188,36 +266,17 @@ namespace Lastfm
 
         private string BuildGetUrl ()
         {
-            if (request_type == RequestType.AuthenticatedRead) {
-                parameters.Add ("sk", LastfmCore.Account.SessionKey);
-            }
-
-            StringBuilder url = new StringBuilder (API_ROOT);
-            url.AppendFormat ("?method={0}", method);
-            url.AppendFormat ("&api_key={0}", LastfmCore.ApiKey);
-            foreach (KeyValuePair<string, string> param in parameters) {
-                url.AppendFormat ("&{0}={1}", param.Key, Uri.EscapeDataString (param.Value));
-            }
             if (request_type == RequestType.AuthenticatedRead || request_type == RequestType.SessionRequest) {
-                url.AppendFormat ("&api_sig={0}", GetSignature ());
+                incremental_data.AppendFormat ("&api_sig={0}", GetSignature ());
             }
 
-            return url.ToString ();
+            return incremental_data.ToString ();
         }
 
         private string BuildPostData ()
         {
-            parameters.Add ("sk", LastfmCore.Account.SessionKey);
-
-            StringBuilder data = new StringBuilder ();
-            data.AppendFormat ("method={0}", method);
-            data.AppendFormat ("&api_key={0}", LastfmCore.ApiKey);
-            foreach (KeyValuePair<string, string> param in parameters) {
-                data.AppendFormat ("&{0}={1}", param.Key, Uri.EscapeDataString (param.Value));
-            }
-            data.AppendFormat ("&api_sig={0}", GetSignature ());
-
-            return data.ToString ();
+            incremental_data.AppendFormat ("&api_sig={0}", GetSignature ());
+            return incremental_data.ToString ();
         }
 
         private string GetSignature ()
@@ -273,7 +332,7 @@ namespace Lastfm
 
         private Stream Get (string uri, string accept)
         {
-            HttpWebRequest request = (HttpWebRequest) WebRequest.Create (uri);
+            var request = (HttpWebRequest)web_request_creator.Create (new Uri (uri));
             if (accept != null) {
                 request.Accept = accept;
             }
@@ -295,7 +354,7 @@ namespace Lastfm
         private Stream Post (string uri, string data)
         {
             // Do not trust docs : it doesn't work if parameters are in the request body
-            HttpWebRequest request = (HttpWebRequest) WebRequest.Create (String.Concat (uri, "?", data));
+            var request = (HttpWebRequest)web_request_creator.Create (new Uri (String.Concat (uri, data)));
             request.UserAgent = LastfmCore.UserAgent;
             request.Timeout = 10000;
             request.Method = "POST";
